cordex.core package
===================

Subpackages
-----------

.. toctree::

   cordex.core.regions

Submodules
----------

cordex.core.cf module
---------------------

.. automodule:: cordex.core.cf
   :members:
   :undoc-members:
   :show-inheritance:

cordex.core.domain module
-------------------------

.. automodule:: cordex.core.domain
   :members:
   :undoc-members:
   :show-inheritance:

cordex.core.utils module
------------------------

.. automodule:: cordex.core.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cordex.core
   :members:
   :undoc-members:
   :show-inheritance:
